@@ -163,6 +163,70 @@ class TestRegion:
         assert (10e-9, 10e-9+tol, 20e-9) not in region
         assert (10e-9, 10e-9, 20e-9+tol) not in region
 
+    def test_or(self):
+        # x-direction
+        p11 = (0, 0, 0)
+        p12 = (10e-9, 50e-9, 20e-9)
+        region1 = df.Region(p1=p11, p2=p12)
+
+        p21 = (20e-9, 0, 0)
+        p22 = (30e-9, 50e-9, 20e-9)
+        region2 = df.Region(p1=p21, p2=p22)
+
+        res = region1 | region2
+
+        assert res[0] == 'x'
+        assert res[1] == region1
+        assert res[2] == region2
+        assert region1 | region2 == region2 | region1
+
+        # y-direction
+        p11 = (0, 0, 0)
+        p12 = (10e-9, 50e-9, 20e-9)
+        region1 = df.Region(p1=p11, p2=p12)
+
+        p21 = (0, -50e-9, 0)
+        p22 = (10e-9, -10e-9, 20e-9)
+        region2 = df.Region(p1=p21, p2=p22)
+
+        res = region1 | region2
+
+        assert res[0] == 'y'
+        assert res[1] == region2
+        assert res[2] == region1
+        assert region1 | region2 == region2 | region1
+
+        # z-direction
+        p11 = (0, 0, 0)
+        p12 = (100e-9, 50e-9, 20e-9)
+        region1 = df.Region(p1=p11, p2=p12)
+
+        p21 = (0, 0, 20e-9)
+        p22 = (100e-9, 50e-9, 30e-9)
+        region2 = df.Region(p1=p21, p2=p22)
+
+        res = region1 | region2
+
+        assert res[0] == 'z'
+        assert res[1] == region1
+        assert res[2] == region2
+        assert region1 | region2 == region2 | region1
+
+        # Exceptions
+        p11 = (0, 0, 0)
+        p12 = (100e-9, 50e-9, 20e-9)
+        region1 = df.Region(p1=p11, p2=p12)
+
+        p21 = (0, 0, 10e-9)
+        p22 = (100e-9, 50e-9, 30e-9)
+        region2 = df.Region(p1=p21, p2=p22)
+
+        with pytest.raises(ValueError):
+            res = region1 | region2
+
+        with pytest.raises(TypeError):
+            res = region1 | 5
+
     def test_mpl(self):
         p1 = (-50e-9, -50e-9, 0)
         p2 = (50e-9, 50e-9, 20e-9)
